==> sale-3.5.1.jar: filiale/xiangyun/sqls/machineChargeQuery.sql <==
select *
from (SELECT *
           , LEFT(price , len(price) - 1)   f_price    --预收气价
           , LEFT(preprice , (len(preprice) - 1)) f_preprice --应收气价
           , LEFT(realamount , (len(realamount) - 1)) f_realamount
           , LEFT(oughtfee , (len(oughtfee) - 1)) f_oughtfee
      FROM (SELECT hd.id                                                                                id,
--                    hd.f_oughtfee,                                                                                     --预收气费
                   hd.f_oughtamount,                                                                                  --购气量
--                    hd.f_oughtfee - hd.f_oughtamount * isnull(sp.f_add_price, 0)                         f_realamount, --应收气费
--                     f_oughtfee                        f_realamount, --应收气费
                   hd.f_input_date,
                   case when sd.id is null then '否' else '是' end                                      f_refund,
                   case when sd.id is null then 0 else hd.f_oughtamount * isnull(sp.f_add_price, 0) end f_refundfee,
                   ui.f_userinfo_code,
                   ui.f_user_name,
                   gd.f_meter_brand,
                   sd.f_operate_date                                                                    f_refund_date,
                   hd.f_orgid,
                   hd.f_orgname,
                   hd.f_depid,
                   hd.f_depname,
                   hd.f_operatorid,
                   hd.f_operator,
                   uf.f_meternumber,
                   uf.f_user_type,
                   uf.f_gasproperties,
                   ua.f_address,
          case
          when hd.f_price_type = '应交费' then
          isnull(hd.f_stair_price1, 0)
          else
          (case
          when isnull(hd.f_stair_price1, 0) - isnull(sp.f_add_price, 0) < 0 then 0
          else isnull(hd.f_stair_price1, 0) - isnull(sp.f_add_price, 0) end) end f_stair_price1,
          isnull(f_stair_gas1, 0)                                                             f_stair_gas1,
          case
          when hd.f_price_type = '应交费' then
          isnull(f_stair_money1, 0)
          else
          (isnull(f_stair_price1, 0) - isnull(sp.f_add_price, 0)) *
          f_stair_gas1 end                                                        f_stair_money1,
          case
          when hd.f_price_type = '应交费' then
          isnull(f_stair_price2, 0)
          else (case
          when isnull(f_stair_price2, isnull(sp.f_add_price, 0)) -
          isnull(sp.f_add_price, 0) < 0 then 0
          else isnull(f_stair_price2, isnull(sp.f_add_price, 0)) -
          isnull(sp.f_add_price, 0) end)
          end                                                                             f_stair_price2,
          isnull(f_stair_gas2, 0)                                                             f_stair_gas2,
          case
          when hd.f_price_type = '应交费' then
          isnull(f_stair_money2, 0)
          else
          (isnull(f_stair_price2, isnull(sp.f_add_price, 0)) - isnull(sp.f_add_price, 0)) *
          f_stair_gas2 end                                                        f_stair_money2,
          case
          when hd.f_price_type = '应交费' then
          isnull(f_stair_price3, 0)
          else
          (case
          when isnull(f_stair_price3, isnull(sp.f_add_price, 0)) -
          isnull(sp.f_add_price, 0) < 0 then 0
          else isnull(f_stair_price3, isnull(sp.f_add_price, 0)) -
          isnull(sp.f_add_price, 0) end) end                                f_stair_price3,
          isnull(f_stair_gas3, 0)                                                             f_stair_gas3,
          case
          when hd.f_price_type = '应交费' then
          isnull(f_stair_money3, 0)
          else
          (isnull(f_stair_price3, isnull(sp.f_add_price, 0)) - isnull(sp.f_add_price, 0)) *
          f_stair_gas3 end                                                        f_stair_money3,
                   CAST((SELECT '' + CAST(CONVERT(DECIMAL(18, 3), f_price) AS VARCHAR) + '|'
                         FROM t_chargeprice cp
                         WHERE hd.id = cp.f_hand_id
                           and cp.f_gas > 0
                         FOR xml path ( '' )) AS VARCHAR)                                               price,
                   CAST((SELECT '' + CAST(CONVERT(DECIMAL(18, 3), f_price - isnull(sp.f_add_price, 0)) AS VARCHAR) + '|'
                         FROM t_chargeprice cp
                         WHERE hd.id = cp.f_hand_id
                           and cp.f_gas > 0
                         FOR xml path ( '' )) AS VARCHAR)                                               preprice,

          CAST((SELECT '' + CAST(CONVERT(DECIMAL(18, 3), f_oughtamount * (f_price - isnull(sp.f_add_price, 0))) AS VARCHAR) + '|'
          FROM t_chargeprice cp
          WHERE hd.id = cp.f_hand_id
          and cp.f_gas > 0
          FOR xml path ( '' )) AS VARCHAR)                                               realamount,

          CAST((SELECT '' + CAST(CONVERT(DECIMAL(18, 3), f_oughtamount * f_price) AS VARCHAR) + '|'
          FROM t_chargeprice cp
          WHERE hd.id = cp.f_hand_id
          and cp.f_gas > 0
          FOR xml path ( '' )) AS VARCHAR)                                               oughtfee
            FROM t_handplan hd
                     left join t_userinfo ui on ui.f_userinfo_id = hd.f_userinfo_id
                     left join t_userfiles uf on uf.f_userfiles_id = hd.f_userfiles_id
                     LEFT JOIN t_gasbrand gd ON uf.f_gasbrand_id = gd.id
                     left join t_user_address ua on uf.f_useraddress_id = ua.id
                     LEFT JOIN t_stairprice sp ON sp.id = hd.f_stairprice_id
                     LEFT JOIN t_surplus_detail sd ON hd.f_surplus_id = sd.id
            WHERE hd.f_hand_state = '有效'
              and hd.f_meter_state = '已抄表'
              and {condition}) ss
      union all
      SELECT *
              , LEFT(price , len(price) - 1)   f_price    --预收气价
              , LEFT(preprice , (len(preprice) - 1)) f_preprice --应收气价
              , LEFT(realamount , (len(realamount) - 1)) f_realamount
              , LEFT(oughtfee , (len(oughtfee) - 1)) f_oughtfee
      FROM (SELECT hd.id                                                                                id,
--                    hd.f_oughtfee,                                                                                     --预收气费
                   hd.f_oughtamount,                                                                                  --购气量
--                    hd.f_oughtfee - hd.f_oughtamount * isnull(sp.f_add_price, 0)                         f_realamount, --应收气费
--           f_oughtfee                        f_realamount, --应收气费
                   hd.f_input_date,
                   case when sd.id is null then '否' else '是' end                                      f_refund,
                   case when sd.id is null then 0 else hd.f_oughtamount * isnull(sp.f_add_price, 0) end f_refundfee,
                   ui.f_userinfo_code,
                   ui.f_user_name,
                   gd.f_meter_brand,
                   sd.f_operate_date                                                                    f_refund_date,
                   hd.f_orgid,
                   hd.f_orgname,
                   hd.f_depid,
                   hd.f_depname,
                   hd.f_operatorid,
                   hd.f_operator,
                   uf.f_meternumber,
                   uf.f_user_type,
                   uf.f_gasproperties,
                   ua.f_address,
          case
          when hd.f_price_type = '应交费' then
          isnull(hd.f_stair_price1, 0)
          else
          (case
          when isnull(hd.f_stair_price1, 0) - isnull(sp.f_add_price, 0) < 0 then 0
          else isnull(hd.f_stair_price1, 0) - isnull(sp.f_add_price, 0) end) end f_stair_price1,
          isnull(f_stair_gas1, 0)                                                             f_stair_gas1,
          case
          when hd.f_price_type = '应交费' then
          isnull(f_stair_money1, 0)
          else
          (isnull(f_stair_price1, 0) - isnull(sp.f_add_price, 0)) *
          f_stair_gas1 end                                                        f_stair_money1,
          case
          when hd.f_price_type = '应交费' then
          isnull(f_stair_price2, 0)
          else (case
          when isnull(f_stair_price2, isnull(sp.f_add_price, 0)) -
          isnull(sp.f_add_price, 0) < 0 then 0
          else isnull(f_stair_price2, isnull(sp.f_add_price, 0)) -
          isnull(sp.f_add_price, 0) end)
          end                                                                             f_stair_price2,
          isnull(f_stair_gas2, 0)                                                             f_stair_gas2,
          case
          when hd.f_price_type = '应交费' then
          isnull(f_stair_money2, 0)
          else
          (isnull(f_stair_price2, isnull(sp.f_add_price, 0)) - isnull(sp.f_add_price, 0)) *
          f_stair_gas2 end                                                        f_stair_money2,
          case
          when hd.f_price_type = '应交费' then
          isnull(f_stair_price3, 0)
          else
          (case
          when isnull(f_stair_price3, isnull(sp.f_add_price, 0)) -
          isnull(sp.f_add_price, 0) < 0 then 0
          else isnull(f_stair_price3, isnull(sp.f_add_price, 0)) -
          isnull(sp.f_add_price, 0) end) end                                f_stair_price3,
          isnull(f_stair_gas3, 0)                                                             f_stair_gas3,
          case
          when hd.f_price_type = '应交费' then
          isnull(f_stair_money3, 0)
          else
          (isnull(f_stair_price3, isnull(sp.f_add_price, 0)) - isnull(sp.f_add_price, 0)) *
          f_stair_gas3 end                                                        f_stair_money3,
                   CAST((SELECT '' + CAST(CONVERT(DECIMAL(18, 3), f_price) AS VARCHAR) + '|'
                         FROM t_chargeprice cp
                         WHERE hd.id = cp.f_hand_id
                           and cp.f_gas > 0
                         FOR xml path ( '' )) AS VARCHAR)                                               price,
                   CAST((SELECT '' + CAST(CONVERT(DECIMAL(18, 3), f_price - isnull(sp.f_add_price, 0)) AS VARCHAR) + '|'
                         FROM t_chargeprice cp
                         WHERE hd.id = cp.f_hand_id
                           and cp.f_gas > 0
                         FOR xml path ( '' )) AS VARCHAR)                                               preprice,

          CAST((SELECT '' + CAST(CONVERT(DECIMAL(18, 3), f_oughtamount * (f_price - isnull(sp.f_add_price, 0))) AS VARCHAR) + '|'
          FROM t_chargeprice cp
          WHERE hd.id = cp.f_hand_id
          and cp.f_gas > 0
          FOR xml path ( '' )) AS VARCHAR)                                               realamount,

          CAST((SELECT '' + CAST(CONVERT(DECIMAL(18, 3), f_oughtamount * f_price) AS VARCHAR) + '|'
          FROM t_chargeprice cp
          WHERE hd.id = cp.f_hand_id
          and cp.f_gas > 0
          FOR xml path ( '' )) AS VARCHAR)                                               oughtfee
            FROM t_web_handplan hd
                     left join t_userinfo ui on ui.f_userinfo_id = hd.f_userinfo_id
                     left join t_userfiles uf on uf.f_userfiles_id = hd.f_userfiles_id
                     LEFT JOIN t_gasbrand gd ON uf.f_gasbrand_id = gd.id
                     left join t_user_address ua on uf.f_useraddress_id = ua.id
                     LEFT JOIN t_stairprice sp ON sp.id = hd.f_stairprice_id
                     LEFT JOIN t_surplus_detail sd ON hd.f_surplus_id = sd.id
            WHERE hd.f_hand_state = '有效'
              and hd.f_meter_state = '已抄表'
              and {condition}
              and f_oughtamount
                > 0) ss) allover
order by f_input_date desc

==> sale-3.5.4.jar: filiale/xiangyun/sqls/machineChargeQuery.sql <==
select *
from (SELECT *
           , LEFT(price , len(price) - 1)   f_price    --预收气价
           , LEFT(preprice , (len(preprice) - 1)) f_preprice --应收气价
           , LEFT(realamount , (len(realamount) - 1)) f_realamount
           , LEFT(oughtfee , (len(oughtfee) - 1)) f_oughtfee
      FROM (SELECT hd.id                                                                                id,
--                    hd.f_oughtfee,                                                                                     --预收气费
                   hd.f_oughtamount,                                                                                  --购气量
                  case
                  when hd.f_price_type = '应交费' then (hd.f_oughtfee + hd.f_oughtamount * isnull(sp.f_add_price, 0))
                  else
                  hd.f_oughtfee end f_preoughtfee,
                  case
                  when hd.f_price_type = '应交费' then hd.f_oughtfee
                  else  (hd.f_oughtfee - hd.f_oughtamount * isnull(sp.f_add_price, 0)) end  f_realoughtfee,
--                    hd.f_oughtfee - hd.f_oughtamount * isnull(sp.f_add_price, 0)                         f_realamount, --应收气费
--                     f_oughtfee                        f_realamount, --应收气费
                   hd.f_input_date,
                   case when sd.id is null then '否' else '是' end                                      f_refund,
                   case when sd.id is null then 0 else hd.f_oughtamount * isnull(sp.f_add_price, 0) end f_refundfee,
                   ui.f_userinfo_code,
                   ui.f_user_name,
                   gd.f_meter_brand,
                   sd.f_operate_date                                                                    f_refund_date,
                   hd.f_orgid,
                   hd.f_orgname,
                   hd.f_depid,
                   hd.f_depname,
                   hd.f_operatorid,
                   hd.f_operator,
                   uf.f_meternumber,
                   uf.f_user_type,
                   uf.f_gasproperties,
                   ua.f_address,
          case
          when hd.f_price_type = '应交费' then
          isnull(hd.f_stair_price1, 0)
          else
          (case
          when isnull(hd.f_stair_price1, 0) - isnull(sp.f_add_price, 0) < 0 then 0
          else isnull(hd.f_stair_price1, 0) - isnull(sp.f_add_price, 0) end) end f_stair_price1,
          isnull(f_stair_gas1, 0)                                                             f_stair_gas1,
          case
          when hd.f_price_type = '应交费' then
          isnull(f_stair_money1, 0)
          else
          (isnull(f_stair_price1, 0) - isnull(sp.f_add_price, 0)) *
          f_stair_gas1 end                                                        f_stair_money1,
          case
          when hd.f_price_type = '应交费' then
          isnull(f_stair_price2, 0)
          else (case
          when isnull(f_stair_price2, isnull(sp.f_add_price, 0)) -
          isnull(sp.f_add_price, 0) < 0 then 0
          else isnull(f_stair_price2, isnull(sp.f_add_price, 0)) -
          isnull(sp.f_add_price, 0) end)
          end                                                                             f_stair_price2,
          isnull(f_stair_gas2, 0)                                                             f_stair_gas2,
          case
          when hd.f_price_type = '应交费' then
          isnull(f_stair_money2, 0)
          else
          (isnull(f_stair_price2, isnull(sp.f_add_price, 0)) - isnull(sp.f_add_price, 0)) *
          f_stair_gas2 end                                                        f_stair_money2,
          case
          when hd.f_price_type = '应交费' then
          isnull(f_stair_price3, 0)
          else
          (case
          when isnull(f_stair_price3, isnull(sp.f_add_price, 0)) -
          isnull(sp.f_add_price, 0) < 0 then 0
          else isnull(f_stair_price3, isnull(sp.f_add_price, 0)) -
          isnull(sp.f_add_price, 0) end) end                                f_stair_price3,
          isnull(f_stair_gas3, 0)                                                             f_stair_gas3,
          case
          when hd.f_price_type = '应交费' then
          isnull(f_stair_money3, 0)
          else
          (isnull(f_stair_price3, isnull(sp.f_add_price, 0)) - isnull(sp.f_add_price, 0)) *
          f_stair_gas3 end                                                        f_stair_money3,
                   CAST((SELECT '' + CAST(CONVERT(DECIMAL(18, 3), f_price) AS VARCHAR) + '|'
                         FROM t_chargeprice cp
                         WHERE hd.id = cp.f_hand_id
                           and cp.f_gas > 0
                         FOR xml path ( '' )) AS VARCHAR)                                               price,
                   CAST((SELECT '' + CAST(CONVERT(DECIMAL(18, 3), f_price - isnull(sp.f_add_price, 0)) AS VARCHAR) + '|'
                         FROM t_chargeprice cp
                         WHERE hd.id = cp.f_hand_id
                           and cp.f_gas > 0
                         FOR xml path ( '' )) AS VARCHAR)                                               preprice,

          CAST((SELECT '' + CAST(CONVERT(DECIMAL(18, 3), f_oughtamount * (f_price - isnull(sp.f_add_price, 0))) AS VARCHAR) + '|'
          FROM t_chargeprice cp
          WHERE hd.id = cp.f_hand_id
          and cp.f_gas > 0
          FOR xml path ( '' )) AS VARCHAR)                                               oughtfee,

          CAST((SELECT '' + CAST(CONVERT(DECIMAL(18, 3), f_oughtamount * f_price) AS VARCHAR) + '|'
          FROM t_chargeprice cp
          WHERE hd.id = cp.f_hand_id
          and cp.f_gas > 0
          FOR xml path ( '' )) AS VARCHAR)                                               realamount
            FROM t_handplan hd
                     left join t_userinfo ui on ui.f_userinfo_id = hd.f_userinfo_id
                     left join t_userfiles uf on uf.f_userfiles_id = hd.f_userfiles_id
                     LEFT JOIN t_gasbrand gd ON uf.f_gasbrand_id = gd.id
                     left join t_user_address ua on uf.f_useraddress_id = ua.id
                     LEFT JOIN t_stairprice sp ON sp.id = hd.f_stairprice_id
                     LEFT JOIN t_surplus_detail sd ON hd.f_surplus_id = sd.id
            WHERE hd.f_hand_state = '有效'
              and hd.f_meter_state = '已抄表'
              and {condition}) ss
      union all
      SELECT *
              , LEFT(price , len(price) - 1)   f_price    --预收气价
              , LEFT(preprice , (len(preprice) - 1)) f_preprice --应收气价
              , LEFT(realamount , (len(realamount) - 1)) f_realamount
              , LEFT(oughtfee , (len(oughtfee) - 1)) f_oughtfee
      FROM (SELECT hd.id                                                                                id,
--                    hd.f_oughtfee,                                                                                     --预收气费
                   hd.f_oughtamount,                                                                                  --购气量
--                    hd.f_oughtfee - hd.f_oughtamount * isnull(sp.f_add_price, 0)                         f_realamount, --应收气费
--           f_oughtfee                        f_realamount, --应收气费
                  case
                  when hd.f_price_type = '应交费' then (hd.f_oughtfee + hd.f_oughtamount * isnull(sp.f_add_price, 0))
                  else
                 hd.f_oughtfee end f_preoughtfee,
                  case
                  when hd.f_price_type = '应交费' then hd.f_oughtfee
                  else  (hd.f_oughtfee - hd.f_oughtamount * isnull(sp.f_add_price, 0)) end  f_realoughtfee,
                   hd.f_input_date,
                   case when sd.id is null then '否' else '是' end                                      f_refund,
                   case when sd.id is null then 0 else hd.f_oughtamount * isnull(sp.f_add_price, 0) end f_refundfee,
                   ui.f_userinfo_code,
                   ui.f_user_name,
                   gd.f_meter_brand,
                   sd.f_operate_date                                                                    f_refund_date,
                   hd.f_orgid,
                   hd.f_orgname,
                   hd.f_depid,
                   hd.f_depname,
                   hd.f_operatorid,
                   hd.f_operator,
                   uf.f_meternumber,
                   uf.f_user_type,
                   uf.f_gasproperties,
                   ua.f_address,
          case
          when hd.f_price_type = '应交费' then
          isnull(hd.f_stair_price1, 0)
          else
          (case
          when isnull(hd.f_stair_price1, 0) - isnull(sp.f_add_price, 0) < 0 then 0
          else isnull(hd.f_stair_price1, 0) - isnull(sp.f_add_price, 0) end) end f_stair_price1,
          isnull(f_stair_gas1, 0)                                                             f_stair_gas1,
          case
          when hd.f_price_type = '应交费' then
          isnull(f_stair_money1, 0)
          else
          (isnull(f_stair_price1, 0) - isnull(sp.f_add_price, 0)) *
          f_stair_gas1 end                                                        f_stair_money1,
          case
          when hd.f_price_type = '应交费' then
          isnull(f_stair_price2, 0)
          else (case
          when isnull(f_stair_price2, isnull(sp.f_add_price, 0)) -
          isnull(sp.f_add_price, 0) < 0 then 0
          else isnull(f_stair_price2, isnull(sp.f_add_price, 0)) -
          isnull(sp.f_add_price, 0) end)
          end                                                                             f_stair_price2,
          isnull(f_stair_gas2, 0)                                                             f_stair_gas2,
          case
          when hd.f_price_type = '应交费' then
          isnull(f_stair_money2, 0)
          else
          (isnull(f_stair_price2, isnull(sp.f_add_price, 0)) - isnull(sp.f_add_price, 0)) *
          f_stair_gas2 end                                                        f_stair_money2,
          case
          when hd.f_price_type = '应交费' then
          isnull(f_stair_price3, 0)
          else
          (case
          when isnull(f_stair_price3, isnull(sp.f_add_price, 0)) -
          isnull(sp.f_add_price, 0) < 0 then 0
          else isnull(f_stair_price3, isnull(sp.f_add_price, 0)) -
          isnull(sp.f_add_price, 0) end) end                                f_stair_price3,
          isnull(f_stair_gas3, 0)                                                             f_stair_gas3,
          case
          when hd.f_price_type = '应交费' then
          isnull(f_stair_money3, 0)
          else
          (isnull(f_stair_price3, isnull(sp.f_add_price, 0)) - isnull(sp.f_add_price, 0)) *
          f_stair_gas3 end                                                        f_stair_money3,
                   CAST((SELECT '' + CAST(CONVERT(DECIMAL(18, 3), f_price) AS VARCHAR) + '|'
                         FROM t_chargeprice cp
                         WHERE hd.id = cp.f_hand_id
                           and cp.f_gas > 0
                         FOR xml path ( '' )) AS VARCHAR)                                               price,
                   CAST((SELECT '' + CAST(CONVERT(DECIMAL(18, 3), f_price - isnull(sp.f_add_price, 0)) AS VARCHAR) + '|'
                         FROM t_chargeprice cp
                         WHERE hd.id = cp.f_hand_id
                           and cp.f_gas > 0
                         FOR xml path ( '' )) AS VARCHAR)                                               preprice,

          CAST((SELECT '' + CAST(CONVERT(DECIMAL(18, 3), f_oughtamount * (f_price - isnull(sp.f_add_price, 0))) AS VARCHAR) + '|'
          FROM t_chargeprice cp
          WHERE hd.id = cp.f_hand_id
          and cp.f_gas > 0
          FOR xml path ( '' )) AS VARCHAR)                                               oughtfee,

          CAST((SELECT '' + CAST(CONVERT(DECIMAL(18, 3), f_oughtamount * f_price) AS VARCHAR) + '|'
          FROM t_chargeprice cp
          WHERE hd.id = cp.f_hand_id
          and cp.f_gas > 0
          FOR xml path ( '' )) AS VARCHAR)                                              realamount
            FROM t_web_handplan hd
                     left join t_userinfo ui on ui.f_userinfo_id = hd.f_userinfo_id
                     left join t_userfiles uf on uf.f_userfiles_id = hd.f_userfiles_id
                     LEFT JOIN t_gasbrand gd ON uf.f_gasbrand_id = gd.id
                     left join t_user_address ua on uf.f_useraddress_id = ua.id
                     LEFT JOIN t_stairprice sp ON sp.id = hd.f_stairprice_id
                     LEFT JOIN t_surplus_detail sd ON hd.f_surplus_id = sd.id
            WHERE hd.f_hand_state = '有效'
              and hd.f_meter_state = '已抄表'
              and {condition}
              and f_oughtamount
                > 0) ss) allover
order by f_input_date desc
